@@ -22,7 +22,7 @@ class HardwareInfo:
 
         for k, v in dic.items():
             if k in ['cpu_id', 'cpu_name', 'arch_name', 'chip_name', 'vendor_name', 'board_name',
-                'ld_script', 'flash_program', 'toolchain_prefix'] and v:
+                     'ld_script', 'flash_program', 'toolchain_prefix'] and v:
                 self.__dict__[k] = v
             else:
                 if type(v) == dict:
@@ -49,6 +49,31 @@ class HardwareInfo:
 
         self.cpu_list = {}
 
+    def check(self, type):
+        if type == 'chip':
+            if len(self.cpu_list) == 0:
+                if not self.cpu_name:
+                    return 'chip component must set chip.cpu_name field'
+                if not self.vendor_name:
+                    return 'chip component must set chip.vendor_name field'
+                if not self.ld_script:
+                    return 'chip component must set chip.ld_script field'
+                if not self.flash_program:
+                    logger.warn('chip component flash_program field')
+            else:
+                for _, v in self.cpu_list.items():
+                    if 'cpu_name' in v and (not v['cpu_name']):
+                        return 'chip component must set chip.cpu_name field'
+                    if (not self.ld_script) and ('ld_script' in v and (not v['ld_script'])):
+                        return 'chip component must set chip.ld_script field'
+
+        elif type == 'board':
+            if not self.chip_name:
+                return 'board component must set chip.chip_name field'
+        elif type == 'solution':
+            if not (self.board_name or self.chip_name or (self.cpu_name and self.ld_script)):
+                return "Solution must set board_name or chip_name, or must set cpu_name and ld_script"
+
     def update_path(self, path):
         if self.ld_script:
             self.ld_script = os.path.join(path, self.ld_script)
@@ -69,7 +94,6 @@ class HardwareInfo:
             elif not v and info.__dict__[k]:
                 self.__dict__[k] = info.__dict__[k]
 
-
     def out(self, hw_key=None):
         text = ''
 
@@ -146,7 +170,7 @@ class HardwareInfo:
 
         if text:
             if hw_key in ['board', 'chip', 'solution']:
-                text =text_head + hw_key + ':\n' + text
+                text = text_head + hw_key + ':\n' + text
             else:
                 text = 'hw_info:\n' + text
 
@@ -241,6 +265,8 @@ class Package(object):
 
     def load(self, filename):
         conf = yaml_load(filename)
+        if not conf:
+            return
 
         for k, v in conf.items():
             if v:
@@ -269,7 +295,11 @@ class Package(object):
             logger.error(
                 '%s `type` must be "solution" or "common" or "board" or "chip".' % filename)
             exit(-1)
+        text = self.hw_info.check(self.type)
 
+        if text:
+            logger.error(self.name + ' ' + text)
+            exit(-1)
 
     def show(self):
         for k, v in self.__dict__.items():
@@ -329,7 +359,6 @@ class Package(object):
 {install}
 {export}'''
 
-
         return text.format(
             name=self.text_out('name', self.name,
                                '# <必选项> 包名称 （符合C语言变量命名规则），长度少于等于64字节'),
@@ -354,11 +383,11 @@ class Package(object):
             def_config=self.def_config_out()
         )
 
-
-    def save(self):
+    def save(self, filename):
+        print(filename)
         text = self.dumps()
         try:
-            with codecs.open(self.filename, 'w') as f:
+            with codecs.open(filename or self.filename, 'w') as f:
                 f.write(text)
             return True
         except:
@@ -388,7 +417,6 @@ class Package(object):
                 for k, v in self.author.items():
                     text += '  {}: {}\n'.format(k, v)
 
-
         return text
 
     def dict_out(self, k, v):
@@ -439,7 +467,7 @@ class Package(object):
                     text += '      - "%s"\n' % src
 
         notes = {
-        'install': '''## 第六部分：安装信息
+            'install': '''## 第六部分：安装信息
 # install:
 #   - dest: include/                       # 安装的目的路径 dest是相当路径，通常是相对于YoC SDK 安装目录
 #     source:                              # 安装源列表
