@@ -176,7 +176,7 @@ class Solution:
                 solution_hw_info.__dict__[k] = v
 
         # soution 的hw_info 优先
-        solution_hw_info.merge(self.solution_component.hw_info)
+        solution_hw_info.merge(self.solution_component.hw_info, True)
 
         if solution_hw_info.cpu_name == '':
             logger.error("not found cpu_id, please set cpu_id")
