@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2015-2020 Alibaba Group Holding Limited
+# Copyright (C) 2019-2020 Alibaba Group Holding Limited
 
 
 from __future__ import print_function
@@ -11,12 +11,12 @@ import os
 
 class Rename(Command):
     common = True
-    helpSummary = "component rename"
+    helpSummary = "Component rename <old_name> to <new_name>"
     helpUsage = """
-%prog [<component>...]
+%prog <old_name> <new_name>
 """
     helpDescription = """
-component rename.
+Component rename <old_name> to <new_name>.
 """
 
     def Execute(self, opt, args):
@@ -34,10 +34,10 @@ component rename.
                                 c.pack.depends.remove(v)
                         c.pack.depends.append({component.name: component.version})
                         c.pack.save()
-                        print("component %s package.yaml is upgraded." % c.name)
-                    print("component `%s` -> `%s` success." % (old_name, new_name))
+                        put_string("component %s package.yaml is upgraded." % c.name)
+                    put_string("component `%s` -> `%s` success." % (old_name, new_name))
                 else:
-                    print("component rename fail.")
+                    put_string("component rename fail.")
             else:
-                print("component `%s` not found." % old_name)
+                put_string("component `%s` not found." % old_name)
 
