@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2015-2020 Alibaba Group Holding Limited
+# Copyright (C) 2019-2020 Alibaba Group Holding Limited
 
 
 from __future__ import print_function
@@ -8,6 +8,7 @@ import os
 import shutil
 import pickle
 import json
+import codecs
 
 from .tools import *
 from .component import *
@@ -50,7 +51,7 @@ class Configure:
     def save(self, yoc_file=None):
         if not yoc_file:
             yoc_file = os.path.join(self.yoc_path, '.yoc')
-        with open(yoc_file, 'w') as f:
+        with codecs.open(yoc_file, 'w', 'UTF-8') as f:
             for k, v in self.__dict__.items():
                 if k not in ['yoc_path', 'init', 'repo', 'gitee_token'] and v:
                     f.write("{}: {}\n".format(k, v))
@@ -149,11 +150,18 @@ class YoC:
                 depends_on.append(c)
         return depends_on
 
-    def getSolution(self):
+    def getSolution(self, board_name=None):
         for component in self.components:
             if component.path == os.getcwd():
+                if board_name:
+                    if self.components.get(board_name):
+                        component.load_package()
+                        component.hw_info.board_name = board_name
+                    else:
+                        put_string("board component `%s` not found in current workspace, please install it: yoc install %s " %(board_name, board_name))
+                        exit(-1)
                 components = self.components.get_depend(component)
-                components.append(component)
+                components.add(component)
                 solution = Solution(components)
 
                 return solution
@@ -201,9 +209,9 @@ class YoC:
                 self.occ.login()
                 zip_file = component.zip(self.yoc_path)
                 if self.occ.upload(component.version, component.type, zip_file) == 0:
-                    print("component upload success: " + component.name)
+                    put_string("component upload success: " + component.name)
                 else:
-                    print("component upload fail: " + component.name)
+                    put_string("component upload fail: " + component.name)
                 # self.save_version()
 
     def uploadall(self):
@@ -214,9 +222,9 @@ class YoC:
             component.load_package()
             zip_file = component.zip(self.yoc_path)
             if self.occ.upload(component.version, component.type, zip_file) == 0:
-                print("component upload success: " + component.name)
+                put_string("component upload success: " + component.name)
             else:
-                print("component upload fail: " + component.name)
+                put_string("component upload fail: " + component.name)
 
     def update(self):
         for component in self.components:
@@ -228,6 +236,8 @@ class YoC:
         self.occ_components = ComponentGroup()
         for p in repo.projects():
             pack = Component(self.conf)
+            if type(p) == bytes:
+                p = bytes.decode(p)
             pack.loader_json(json.loads(p))
             pack.path = os.path.join(self.conf.yoc_path, pack.path)
             self.occ_components.add(pack)
@@ -257,10 +267,10 @@ class YoC:
             component.load_package()
             component.show()
             # if component.depends:
-            #     print('  ', 'depends:')
+            #     put_string('  ', 'depends:')
             #     for v in component.depends:
-            #         print('    -', v)
+            #         put_string('    -', v)
             # if component.depends_on:
-            #     print('  ', 'depends_on:')
+            #     put_string('  ', 'depends_on:')
             #     for p in component.depends_on:
-            #         print('    -', p.name)
+            #         put_string('    -', p.name)
